%global specversion 2
%global upstream_version ffbaa6a

# Messaging buses
%bcond_without dbus
%bcond_without qmf

# Choose a versioning scheme
%bcond_with pre_release

%if %{defined _unitdir}
%global systemd 1
%else
%global systemd 0
%endif

%if %{with pre_release}
%global mh_release 0.%{specversion}.%{upstream_version}.git
%else
%global mh_release %{specversion}
%endif

Name:           matahari
Version:        0.6.0
Release:        %{mh_release}%{?dist}
Summary:        Matahari QMF Agents for Linux guests

Group:          Applications/System
License:        GPLv2
URL:            http://matahariproject.org

# wget --no-check-certificate -O matahari-matahari-{upstream_version}.tgz https://github.com/matahari/matahari/tarball/{upstream_version}
Source0:        matahari-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# NOTE: The host API uses dbus for the machine uuid
Requires:       dbus
Requires:       qmf > 0.7
Requires:       pcre

Requires:       %{name}-core = %{version}-%{release}
Requires:       %{name}-consoles = %{version}-%{release}
Requires:       %{name}-broker = %{version}-%{release}
Requires:       %{name}-host = %{version}-%{release}
Requires:       %{name}-network = %{version}-%{release}
Requires:       %{name}-rpc = %{version}-%{release}
Requires:       %{name}-service = %{version}-%{release}
Requires:       %{name}-sysconfig = %{version}-%{release}

BuildRequires:  cmake
BuildRequires:  libuuid-devel
BuildRequires:  gcc-c++
BuildRequires:  pcre-devel
BuildRequires:  glib2-devel
BuildRequires:  sigar-devel
BuildRequires:  libcurl-devel
BuildRequires:  nss-devel
BuildRequires:  help2man
BuildRequires:  augeas-devel >= 0.9.0
BuildRequires:  python2-devel

%if %{with qmf}
BuildRequires:  qpid-cpp-client-devel > 0.7
BuildRequires:  qpid-qmf-devel > 0.7
%endif

%if %{with dbus}
BuildRequires:  dbus-devel dbus-glib-devel polkit-devel libxslt
%endif

%if %{defined run_unit_tests}
BuildRequires:  cxxtest
%endif

%description

Matahari provides QMF Agents that can be used to control and manage
various pieces of functionality, using the AMQP protocol.

The Advanced Message Queuing Protocol (AMQP) is an open standard application
layer protocol providing reliable transport of messages.

QMF provides a modeling framework layer on top of qpid (which implements
AMQP).  This interface allows you to manage a host and its various components
as a set of objects with properties and methods.


%package core
License:        GPLv2+
Summary:        Core files for Matahari
Group:          Applications/System

%description core
Core files for Matahari

%if %{with qmf}
%package broker
License:        GPLv2+
Summary:        Optional AMQP Broker for Matahari
Group:          Applications/System
Requires:       %{name}-core = %{version}-%{release}
Requires:       qpid-cpp-server > 0.7
Requires:       qpid-cpp-server-ssl > 0.7
Requires:       qmf > 0.7
Requires:       qpid-tools
Requires(post): chkconfig
Requires(preun):chkconfig
Requires(preun):initscripts

%description broker
Optional AMQP Broker for Matahari
%endif

%package vios-proxy-host
License:        ASL 2.0
Summary:        Network proxy using virtioserial for QEMU host
Group:          Applications/System
Requires:       %{name}-broker = %{version}-%{release}
Requires:       vios-proxy-host
Requires(post):	chkconfig
Requires(preun):	chkconfig
Requires(preun):	initscripts

%description vios-proxy-host
%{name} specific host initialization scripts

%package vios-proxy-guest
License:        ASL 2.0
Summary:        Network proxy using virtioserial for QEMU guest
Group:          Applications/System
Requires:       %{name}-broker = %{version}-%{release}
Requires:       vios-proxy-guest
Requires(post):	chkconfig
Requires(preun):	chkconfig
Requires(preun):	initscripts

%description vios-proxy-guest
%{name} specific guest initialization scripts

%package lib
License:        GPLv2+
Summary:        C libraries used by Matahari agents
Group:          Applications/System
Requires:       %{name}-core = %{version}-%{release}

%description lib
C libraries used by Matahari agents

%package agent-lib
License:        GPLv2+
Summary:        C++ library used by Matahari agents
Group:          Applications/System
Requires:       %{name}-lib = %{version}-%{release}
Requires:       qpid-cpp-client-ssl > 0.7
Requires(pre):  shadow-utils
Requires:       kstart

%description agent-lib
C++ library containing the base class for Matahari agents

%package python
License:        GPLv2+
Summary:        Matahari Python API
Group:          Applications/System
Requires:       python-qpid-qmf

%description python
Python libraries for Matahari

%package shell
License:        GPLv2+
Summary:        Matahari Shell (mhsh)
Group:          Applications/System
Requires:       %{name}-python = %{version}-%{release}

%description shell
Interactive shell for accessing Matahari agents

%package host
License:        GPLv2+
Summary:        QMF agent for remote hosts
Group:          Applications/System
Requires:       %{name}-lib = %{version}-%{release}
Requires:       %{name}-agent-lib = %{version}-%{release}
%ifarch i386 x86_64
Requires:       dmidecode
%endif
Requires(post): chkconfig
Requires(preun):chkconfig
Requires(preun):initscripts
# Power management functions in host agent require tuned
Requires:       tuned

%description host
QMF agent for viewing and controlling remote hosts

%package network
License:        GPLv2+
Summary:        QMF agent for network devices
Group:          Applications/System
Requires:       %{name}-lib = %{version}-%{release}
Requires:       %{name}-agent-lib = %{version}-%{release}
Requires(post): chkconfig
Requires(preun):chkconfig
Requires(preun):initscripts
Obsoletes:      matahari-net < %{version}-%{release}

%description network
QMF agent for viewing and controlling network devices

%package rpc
License:        GPLv2+
Summary:        QMF agent for RPC plugins
Group:          Applications/System
Requires:       %{name}-lib = %{version}-%{release}
Requires:       %{name}-agent-lib = %{version}-%{release}
Requires:       %{name}-python = %{version}-%{release}
Requires(post): chkconfig
Requires(preun):chkconfig
Requires(preun):initscripts

%description rpc
QMF agent for dispatching RPC calls to plugins

%package service
License:        GPLv2+
Summary:        QMF agent for system services
Group:          Applications/System
Requires:       %{name}-lib = %{version}-%{release}
Requires:       %{name}-agent-lib = %{version}-%{release}
Requires(post): chkconfig
Requires(preun):initscripts
Requires(preun):chkconfig

%description service
QMF agent for viewing and controlling system services

%package sysconfig
License:        GPLv2+
Summary:        QMF agent for post boot configuration services
Group:          Applications/System
Requires:       %{name}-lib = %{version}-%{release}
Requires:       %{name}-agent-lib = %{version}-%{release}
Requires:       puppet
Requires(post): chkconfig
Requires(preun):chkconfig
Requires(preun):initscripts

%description sysconfig
QMF agent/console for providing post boot capabilities.

%package devel
License:        GPLv2+
Summary:        Matahari development package
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-lib = %{version}-%{release}
Requires:       %{name}-agent-lib = %{version}-%{release}
Requires:       qpid-cpp-client-devel > 0.7
Requires:       qpid-qmf-devel > 0.7
Requires:       glib2-devel

%description devel
Headers and shared libraries for developing Matahari agents.

%package consoles
License:        GPLv2+
Summary:        QMF console for monitoring various agents
Group:          Applications/System
Requires:       %{name}-lib = %{version}-%{release}
Requires:       %{name}-agent-lib = %{version}-%{release}

%description consoles
QMF console for monitoring various agents

%prep
%setup -q -n matahari-%{version}

%build
%{cmake} -DCMAKE_BUILD_TYPE=RelWithDebInfo %{!?with_qmf: -DWITH-QMF:BOOL=OFF} %{!?with_dbus: -DWITH-DBUS:BOOL=OFF} -Dinitdir=%{_initddir} -Dsysconfdir=%{_sysconfdir} .
make -f Makefile %{?_smp_mflags}
%if %{defined run_unit_tests}
cd src/tests && ctest -V
%endif

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} -f Makefile install

%if %{systemd}
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-service
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-network
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-host
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-rpc
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-sysconfig
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-sysconfig-console
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-broker
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-vios-proxy-host
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/matahari-vios-proxy-guest
%endif

%post -n matahari-lib -p /sbin/ldconfig
%postun -n matahari-lib -p /sbin/ldconfig

%post -n matahari-agent-lib -p /sbin/ldconfig
%postun -n matahari-agent-lib
# Can't use -p, gives: '/sbin/ldconfig: relative path `0' used to build cache' error
/sbin/ldconfig

%if %{with qmf}
#== Host

%post host
%if %{systemd}
systemctl --system daemon-reload
%else
/sbin/chkconfig --add matahari-host
%endif
/sbin/service matahari-host condrestart

%preun host
if [ $1 = 0 ]; then
   /sbin/service matahari-host stop >/dev/null 2>&1 || :
%if !%{systemd}
   chkconfig --del matahari-host
%endif
fi

%postun host
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-host condrestart >/dev/null 2>&1 || :
fi

#== Network

%post network
%if %{systemd}
systemctl --system daemon-reload
%else
/sbin/chkconfig --add matahari-network
%endif
/sbin/service matahari-network condrestart

%preun network
if [ $1 = 0 ]; then
   /sbin/service matahari-network stop >/dev/null 2>&1 || :
%if !%{systemd}
   chkconfig --del matahari-network
%endif
fi

%postun network
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-network condrestart >/dev/null 2>&1 || :
fi

#== RPC

%post rpc
%if %{systemd}
systemctl --system daemon-reload
%else
/sbin/chkconfig --add matahari-rpc
%endif
/sbin/service matahari-rpc condrestart

%preun rpc
if [ $1 = 0 ]; then
   /sbin/service matahari-rpc stop >/dev/null 2>&1 || :
%if !%{systemd}
   chkconfig --del matahari-rpc
%endif
fi

%postun rpc
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-rpc condrestart >/dev/null 2>&1 || :
fi

#== Services

%post service
%if %{systemd}
systemctl --system daemon-reload
%else
/sbin/chkconfig --add matahari-service
%endif
/sbin/service matahari-service condrestart

%preun service
if [ $1 = 0 ]; then
   /sbin/service matahari-service stop >/dev/null 2>&1 || :
%if !%{systemd}
   chkconfig --del matahari-service
%endif
fi

%postun service
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-service condrestart >/dev/null 2>&1 || :
fi

#== sysconfig

%post sysconfig
%if %{systemd}
systemctl --system daemon-reload
%else
/sbin/chkconfig --add matahari-sysconfig
%endif
/sbin/service matahari-sysconfig condrestart

%preun sysconfig
if [ $1 = 0 ]; then
   /sbin/service matahari-sysconfig stop >/dev/null 2>&1 || :
%if !%{systemd}
   chkconfig --del matahari-sysconfig
%endif
fi

%postun sysconfig
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-sysconfig condrestart >/dev/null 2>&1 || :
fi

#== Broker

%post broker
%if %{systemd}
systemctl --system daemon-reload
%else
/sbin/chkconfig --add matahari-broker
%endif
/sbin/service matahari-broker condrestart

%preun broker
if [ $1 = 0 ]; then
    /sbin/service matahari-broker stop >/dev/null 2>&1 || :
%if !%{systemd}
    chkconfig --del matahari-broker
%endif
fi

%postun broker
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-broker condrestart >/dev/null 2>&1 || :
fi

#== Vios Proxy Host
%post vios-proxy-host
%if %{systemd}
systemctl --system daemon-reload
%endif
/sbin/service matahari-vios-proxy-host condrestart

%preun vios-proxy-host
if [ $1 = 0 ]; then
    /sbin/service matahari-vios-proxy-host stop >/dev/null 2>&1 || :
%if !%{systemd}
    chkconfig --del matahari-vios-proxy-host
%endif
fi

%postun vios-proxy-host
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-vios-proxy-host condrestart >/dev/null 2>&1 || :
fi

#== Vios Proxy guest
%post vios-proxy-guest
%if %{systemd}
systemctl --system daemon-reload
%endif
/sbin/service matahari-vios-proxy-guest condrestart

%preun vios-proxy-guest
if [ $1 = 0 ]; then
    /sbin/service matahari-vios-proxy-guest stop >/dev/null 2>&1 || :
%if !%{systemd}
    chkconfig --del matahari-vios-proxy-guest
%endif
fi

%postun vios-proxy-guest
if [ "$1" -ge "1" ]; then
    /sbin/service matahari-vios-proxy-guest condrestart >/dev/null 2>&1 || :
fi
#== Core

%pre core
getent group qpidd >/dev/null || groupadd -r qpidd
exit 0

%endif

%clean
test "x%{buildroot}" != "x" && rm -rf %{buildroot}

%files
%defattr(644, root, root, 755)
%doc AUTHORS COPYING

%files agent-lib
%defattr(644, root, root)
%attr(755, -, -) %dir %{_datadir}/matahari/
%doc AUTHORS COPYING

%if %{with qmf}
%{_libdir}/libmcommon_qmf.so.*
%endif

%if %{with dbus}
%{_libdir}/libmcommon_dbus.so.*
%endif

%files lib
%defattr(644, root, root, 755)
%{_libdir}/libmcommon.so.*
%{_libdir}/libmhost.so.*
%{_libdir}/libmnetwork.so.*
%{_libdir}/libmrpc.so.*
%{_libdir}/libmservice.so.*
%{_libdir}/libmsysconfig.so.*
%doc AUTHORS COPYING

%files core
%defattr(644, root, root, 755)
%doc AUTHORS COPYING
%config(noreplace) %{_sysconfdir}/sysconfig/matahari
%if %{with qmf}
%dir %attr(0770, root, qpidd) %{_localstatedir}/lib/%{name}
%endif

%files python
%defattr(644, root, root, 755)
%doc AUTHORS COPYING
%dir %{python_sitelib}/matahari/
%{python_sitelib}/matahari/*.py
%{python_sitelib}/matahari/*.pyc
%{python_sitelib}/matahari/*.pyo

%files shell
%defattr(644, root, root, 755)
%doc AUTHORS COPYING
%attr(755, -, -) %{_bindir}/mhsh
%{python_sitelib}/matahari/shell/*.py
%{python_sitelib}/matahari/shell/*.pyc
%{python_sitelib}/matahari/shell/*.pyo
%{python_sitelib}/matahari/shell/interpreter/*.py
%{python_sitelib}/matahari/shell/interpreter/*.pyc
%{python_sitelib}/matahari/shell/interpreter/*.pyo

%files network
%defattr(644, root, root, 755)
%doc AUTHORS COPYING

%if %{systemd}
%{_unitdir}/matahari-network.service
%endif

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-network
%endif
%attr(755, root, root) %{_sbindir}/matahari-qmf-networkd
%{_mandir}/man8/matahari-qmf-networkd.8*
%endif

%if %{with dbus}
%attr(755, root, root) %{_sbindir}/matahari-dbus-networkd
%config %{_sysconfdir}/dbus-1/system.d/org.matahariproject.Network.conf
%{_datadir}/dbus-1/interfaces/org.matahariproject.Network.xml
%{_datadir}/dbus-1/system-services/org.matahariproject.Network.service
%{_datadir}/polkit-1/actions/org.matahariproject.Network.policy
%endif

%files host
%defattr(644, root, root, 755)
%doc AUTHORS COPYING

%if %{systemd}
%{_unitdir}/matahari-host.service
%endif

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-host
%endif
%attr(755, root, root) %{_sbindir}/matahari-qmf-hostd
%{_mandir}/man8/matahari-qmf-hostd.8*
%endif

%if %{with dbus}
%attr(755, root, root) %{_sbindir}/matahari-dbus-hostd
%config %{_sysconfdir}/dbus-1/system.d/org.matahariproject.Host.conf
%{_datadir}/polkit-1/actions/org.matahariproject.Host.policy
%{_datadir}/dbus-1/interfaces/org.matahariproject.Host.xml
%{_datadir}/dbus-1/system-services/org.matahariproject.Host.service
%endif

%files rpc
%defattr(644, root, root, 755)
%doc AUTHORS COPYING
%attr(0755, -, -) %dir /usr/lib/matahari/plugins

%if %{systemd}
%{_unitdir}/matahari-rpc.service
%endif

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-rpc
%endif
%attr(755, root, root) %{_sbindir}/matahari-qmf-rpcd
%{_mandir}/man8/matahari-qmf-rpcd.8*
%endif

%files service
%defattr(644, root, root, 755)
%doc AUTHORS COPYING

%if %{systemd}
%{_unitdir}/matahari-service.service
%endif

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-service
%endif
%attr(755, root, root) %{_sbindir}/matahari-qmf-serviced
%{_mandir}/man8/matahari-qmf-serviced.8*
%endif

%if %{with dbus}
%attr(755, root, root) %{_sbindir}/matahari-dbus-serviced
%config %{_sysconfdir}/dbus-1/system.d/org.matahariproject.Services.conf
%{_datadir}/dbus-1/interfaces/org.matahariproject.Services.xml
%{_datadir}/dbus-1/system-services/org.matahariproject.Services.service
%{_datadir}/polkit-1/actions/org.matahariproject.Services.policy
%{_datadir}/polkit-1/actions/org.matahariproject.Resources.policy
%endif

%files sysconfig
%defattr(644, root, root, 755)
%doc AUTHORS COPYING

%if %{systemd}
%{_unitdir}/matahari-sysconfig.service
%endif

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-sysconfig
%endif
%attr(755, root, root) %{_sbindir}/matahari-qmf-sysconfigd
%{_mandir}/man8/matahari-qmf-sysconfigd.8*
%endif

%if %{with dbus}
%attr(755, root, root) %{_sbindir}/matahari-dbus-sysconfigd
%config %{_sysconfdir}/dbus-1/system.d/org.matahariproject.Sysconfig.conf
%{_datadir}/dbus-1/interfaces/org.matahariproject.Sysconfig.xml
%{_datadir}/dbus-1/system-services/org.matahariproject.Sysconfig.service
%{_datadir}/polkit-1/actions/org.matahariproject.Sysconfig.policy
%endif

%files consoles
%defattr(644, root, root, 755)
%doc AUTHORS COPYING

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-sysconfig-console
%endif
%attr(755, root, root) %{_sbindir}/matahari-qmf-sysconfig-consoled
%{_mandir}/man8/matahari-qmf-sysconfig-consoled.8*
%attr(755, root, root) %{_sbindir}/matahari-qmf-service-cli
%{_mandir}/man8/matahari-qmf-service-cli.8*

%if %{systemd}
%{_unitdir}/matahari-sysconfig-console.service
%endif
%endif

%if %{with qmf}
%files broker
%defattr(644, root, root, 755)
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-broker
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/matahari-broker
%config(noreplace) %{_sysconfdir}/matahari-broker.conf
%attr(755, root, root) %{_sbindir}/matahari-brokerd
%{_mandir}/man8/matahari-brokerd.8*
%doc AUTHORS COPYING

%if %{systemd}
%{_unitdir}/matahari-broker.service
%else
%ghost %dir %attr(0775, root, qpidd) %{_localstatedir}/run/%{name}
%endif

%else
%exclude %{_sysconfdir}/matahari-broker.conf
%endif

%files vios-proxy-host
%defattr(644, root, root, 755)
%config(noreplace) %{_sysconfdir}/sysconfig/matahari-vios-proxy

%if %{systemd}
%{_unitdir}/matahari-vios-proxy-host.service
%endif

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-vios-proxy-host
%endif
%endif

%files vios-proxy-guest
%defattr(644, root, root, 755)
%{_sysconfdir}/udev/rules.d/99-matahari-guest-agent.rules
%config(noreplace) %{_sysconfdir}/sysconfig/matahari-vios-proxy

%if %{systemd}
%{_unitdir}/matahari-vios-proxy-guest.service
%endif

%if %{with qmf}
%if !%{systemd}
%attr(755, root, root) %{_initddir}/matahari-vios-proxy-guest
%endif
%endif

%files devel
%defattr(644, root, root, 755)
%doc AUTHORS COPYING

%{_libdir}/libm*.so
%{_includedir}/matahari.h
%{_includedir}/matahari/config.h
%{_includedir}/matahari/logging.h
%{_includedir}/matahari/utilities.h
%{_includedir}/matahari/errors.h
%{_includedir}/matahari/dnssrv.h
%{_includedir}/matahari/host.h
%{_includedir}/matahari/network.h
%{_includedir}/matahari/rpc.h
%{_includedir}/matahari/sysconfig.h
%{_includedir}/matahari/services.h
%{_datadir}/cmake/Modules/FindMatahari.cmake
%{_datadir}/cmake/Modules/MatahariMacros.cmake

%if %{with qmf}
%{_includedir}/matahari/agent.h
%{_includedir}/matahari/object.h
%{_includedir}/matahari/mainloop.h
%{_datadir}/cmake/Modules/FindQPID.cmake
%endif

%if %{with dbus}
%{_includedir}/matahari/dbus_common.h
%{_includedir}/matahari/gobject_class.h
%{_datadir}/matahari/schema-to-dbus.xsl
%{_datadir}/matahari/dbus-to-c.xsl
%{_datadir}/matahari/check-policy.xsl
%endif

%changelog
* Fri Jan 13 2012 Zane Bitter <zbitter@redhat.com> 0.6.0-2
- Set correct permissions on mhsh executable.
  Resolves: rhbz#781218

* Mon Jan 2  2012 Zane Bitter <zbitter@redhat.com> 0.6.0-1
- New upstream release

* Fri Oct 21 2011 Adam Stokes <astokes@fedoraproject.org> 0.5.0
- New upstream release

* Mon Sep 26 2011 Russell Bryant <rbryant@redhat.com> 0.4.7-0.2.94a4de1.git
- Only depend on dmidecode on architectures that include it (i386 and x86_64)
- Resolves: rhbz#745386

* Mon Sep 26 2011 Russell Bryant <rbryant@redhat.com> 0.4.7-0.1.94a4de1.git
- Include latest upstream fixes

* Tue Sep 20 2011 Adam Stokes <astokes@fedoraproject.org> 0.4.7-0.1.f4a02ae.git
- New upstream release

* Wed Sep 14 2011 Adam Stokes <astokes@fedoraproject.org> 0.4.5-0.1.59d1fe1.git
- New upstream release

* Fri Sep 09 2011 Adam Stokes <astokes@fedoraproject.org> 0.4.4-0.1.2667bbb.git
- New upstream release

* Mon Aug 29 2011 Adam Stokes <astokes@fedoraproject.org> 0.4.2-3.1.67227ab.git
- Resolves: rhbz #733793 - hostd crashes on startup

* Fri Jul 29 2011 Adam Stokes <astokes@fedoraproject.org> 0.4.2-2
- New upstream release

* Thu Jul 21 2011 Andrew Beekhof <andrew@beekhof.net> 0.4.2-1
- New upstream relase
- Add dbus support
- Make dbus/qmf support optional at build time

* Tue May 3  2011 Andrew Beekhof <andrew@beekhof.net> 0.4.1-2
- Rebuild for new qpid-cpp

* Wed Apr 27 2011 Andrew Beekhof <andrew@beekhof.net> 0.4.1-1
- New upstream relase
- New package structure
- Remove stale dependancy on hal
- Do not start services by default

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-0.1.8003b6c.git.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan 31 2011 Andrew Beekhof <andrew@beekhof.net> - 0.4.0-0.1.8003b6c.git
- Improved modular agent design
- Cross-platform (see mingw32-matahari)
- Added Networking and Services (supporting LSB and OCF scripts) agents

* Wed Sep 29 2010 jkeating - 0.0.5-4
- Rebuilt for gcc bug 634757

* Mon Sep 20 2010 Tom "spot" Callaway <tcallawa@redhat.com> - 0.0.5-3
- fix header and compiler issues in code which were preventing build

* Mon Aug 16 2010 Darryl L. Pierce <dpierce@redhat.com> - 0.0.5-2
- Rebuild for updated Qpid/WMF.

* Wed Jul  7 2010 Darryl L. Pierce <dpierce@redhat.com> - 0.0.5-1
- Rebuild for updated Qpid/QMF.
- Resolves: rhbz602975 - Matahari messages are not accepted by current version of qpid in F13

* Thu Oct 08 2009 Arjun Roy <arroy@redhat.com> - 0.0.4-7
- Refactored for new version of qpidc.

* Fri Oct 02 2009 Kevin Kofler <Kevin@tigcc.ticalc.org> - 0.0.4-6
- Rebuild for new qpidc.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jul 16 2009 Arjun Roy <arroy@redhat.com> - 0.0.4-4
- Changed buildroot value to meet fedora packaging guidelines
- Updated project website

* Mon Jul 13 2009 Arjun Roy <arroy@redhat.com> - 0.0.4-3
- Quietened rpmlint errors and warnings.
- Fixed most gcc warnings.
- Changed init script so it doesn't run by default
- Now rpm specfile makes it so service runs by default instead

* Thu Jul 9 2009 Arjun Roy <arroy@redhat.com> - 0.0.4-2
- Bumped qpidc and qmf version requirements to 0.5.790661.

* Thu Jul 9 2009 Arjun Roy <arroy@redhat.com> - 0.0.4-1
- Removed dependency on boost. Added dependency on pcre.

* Thu Jul 2 2009 Arjun Roy <arroy@redhat.com> - 0.0.3-2
- Fixed bug with not publishing host hypervisor and arch to broker
- Updated aclocal.m4 to match new version of automake

* Tue Jun 30 2009 Arjun Roy <arroy@redhat.com> - 0.0.3-1
- Added getopt and daemonize support
- Added sysV init script support

* Mon Jun 29 2009 Arjun Roy <arroy@redhat.com> - 0.0.2-1
- Now tracks hypervisor and arch using libvirt

* Tue Jun 23 2009 Arjun Roy <arroy@redhat.com> - 0.0.1-1
- Initial rpmspec packaging
